@@ -14,7 +14,7 @@
 # under the License.
 
 
-import imp
+import importlib.util
 import os
 
 from docutils import core
@@ -93,7 +93,12 @@ class AnsibleAutoPluginDirective(Directive):
 
     @staticmethod
     def load_module(filename):
-        return imp.load_source('__ansible_module__', filename)
+        module_spec = importlib.util.spec_from_file_location(
+            '__ansible_module__', filename
+        )
+        module = importlib.util.module_from_spec(module_spec)
+        module_spec.loader.exec_module(module)
+        return module
 
     @staticmethod
     def build_documentation(module):
@@ -174,15 +179,6 @@ class AnsibleAutoPluginDirective(Directive):
                 os.path.basename(role)
             )
         )
-
-        abspath_role = os.path.dirname(os.path.abspath(role))
-        molecule_shared_file = os.path.join(os.path.dirname(abspath_role),
-                                            ".config/molecule/config.yml")
-
-        if os.path.exists(molecule_shared_file):
-            with open(molecule_shared_file) as msf:
-                molecule_defaults = yaml.safe_load(msf.read())
-
         defaults_file = os.path.join(role, 'defaults', 'main.yml')
         if os.path.exists(defaults_file):
             with open(defaults_file) as f:
@@ -235,9 +231,6 @@ class AnsibleAutoPluginDirective(Directive):
                 with open(molecule_file) as f:
                     molecule_conf = yaml.safe_load(f.read())
 
-                if not molecule_conf:
-                    molecule_conf = molecule_defaults
-
                 molecule_section.append(
                     self._yaml_section(
                         to_yaml_data=molecule_conf,
@@ -245,17 +238,7 @@ class AnsibleAutoPluginDirective(Directive):
                     )
                 )
 
-                default_playbook = [molecule_path, test, 'converge.yml']
-
-                provisioner_data = None
-                # Now that we use a shared molecule configuration file, the
-                # molecule.yml file in the role scenarios could be empty or
-                # contains only overriding keys.
-                if molecule_conf:
-                    provisioner_data = molecule_conf.get('provisioner')
-                else:
-                    provisioner_data = molecule_defaults.get('provisioner')
-
+                provisioner_data = molecule_conf.get('provisioner')
                 if provisioner_data:
                     inventory = provisioner_data.get('inventory')
                     if inventory:
@@ -265,13 +248,12 @@ class AnsibleAutoPluginDirective(Directive):
                                 section_title='Molecule Inventory'
                             )
                         )
-                    try:
-                        converge = provisioner_data['playbooks']['converge']
-                        default_playbook = default_playbook[:-1] + [converge]
-                    except KeyError:
-                        pass
 
-                molecule_playbook_path = os.path.join(*default_playbook)
+                molecule_playbook_path = os.path.join(
+                    molecule_path,
+                    test,
+                    'converge.yml'
+                )
                 with open(molecule_playbook_path) as f:
                     molecule_playbook = yaml.safe_load(f.read())
                 molecule_section.append(
